Skip to contents

Add an individual to a file

Usage

add_individual(
  path = ".",
  role = c("aut", "cre", "ctb", "rev", "cph", "fnd", "pbl")
)

Arguments

path

A path to a file or directory. Supported file types:

  • Quarto files (_quarto.yml or *.qmd)

  • R package DESCRIPTION files

  • README files (README.md or README.Rmd)

  • Bookdown index files (index.md or index.Rmd)

role

The role of the person to add. One or multiple of "aut" (author), "cre" (creator/maintainer), "ctb" (contributor), "rev" (reviewer), "cph" (copyright holder), "fnd" (funder), or "pbl" (publisher). Unless you want to an individual to a Quarto or bookdown document. Then you can only specify one role, and "aut" will be added to the author field, #' "rev" to the reviewer field, "cph" to the rightsholder field, "fnd" to the funder field, and "pbl" to the publisher field.