Skip to contents

Ask for keywords This function prompts the user to enter one or more keywords separated by ;. It will continue to prompt the user until at least one keyword is provided. The function returns a character vector of the entered keywords, with leading and trailing whitespace removed.

Usage

ask_keywords()

Value

A character vector of keywords entered by the user.

Examples

if (FALSE) { # \dontrun{
keywords <- ask_keywords()
} # }