Skip to contents

The ORCID iD is a unique, persistent identifier free of charge to researchers. This function prompts the user to enter an ORCID iD and validates its format. The ORCID iD must be in the format 0000-0000-0000-0000 where the last digit can be a number or "X". Empty strings are considered valid to allow optional ORCID iD.

Usage

ask_orcid(prompt = "orcid: ")

Arguments

prompt

A character string to display as a prompt to the user. The default is "orcid: ".

Value

A character string containing the ORCID iD entered by the user.