Skip to contents

The Research Organization Registry (ROR) is a global, community-led registry of open persistent identifiers for research organizations. ROR makes it easy for anyone or any system to disambiguate institution names and connect research organizations to researchers and research outputs.

Usage

ask_ror(prompt)

Arguments

prompt

the string printed when prompting the user for input. Should usually end with a space " ".