Get the list of available organisations
Source:R/get_available_organisations.R
get_available_organisations.RdThis function retrieves the list of available organisations from the local configuration files and locally stored organisations. It returns a list containing the names, languages, licenses, ORCID, Zenodo, ROR, website, and logo of the available organisations.
Value
A list containing the names, languages, licenses, ORCID, Zenodo, ROR, website, and logo of the available organisations.