This function retrieves the default organisation list from the
organisation.yml file in the organisations citeme repository.
The origin of the repository is used to determine the root URL of the
organisation.
Value
An org_list object containing the organisation list.
The function also stores the information in the user's R configuration.
See also
Other organisation:
cache_org(),
get_available_organisations(),
inbo_org_list(),
new_org_item(),
new_org_list(),
org_list_from_url(),
select_license()