Select the individual information to use as a person object
Source: R/individual2person.R
individual2person.RdThis function retrieves the individual information using
select_individual() and converts it to a person object.
If the individual argument is not provided, it will prompt the user to
select an individual.
The person object will include the given name, family name, email, ORCID,
and affiliation (if available) of the selected individual.
Usage
individual2person(individual, role = "aut", lang, org = org_list$new()$read())Arguments
- individual
An optional
individualobject to convert to apersonobject. If not provided, the function will prompt the user to select an individual.- role
The role to use for the
personobject. Defaults to `"aut"“ (author).- lang
The language to use for the affiliation.
- org
An
org_listobject containing the organisation information. Defaults to theorg_listobject read from the current working directory.