Check if a file is tracked and not modified
Source:R/is_tracked_not_modified.R
is_tracked_not_modified.RdCheck if a file is tracked and not modified
See also
Other git:
is_repository(),
ssh_http()
R/is_tracked_not_modified.R
is_tracked_not_modified.RdCheck if a file is tracked and not modified
Other git:
is_repository(),
ssh_http()