Get the default organisation list from a git URL This function retrieves the default organisation list from a git URL. It checks if the organisation list is already cached in the user's R configuration. If it is, it returns the cached version. If not, it attempts to retrieve the organisation list from the specified git URL and caches it for future use.
Source:R/org_list_from_url.R
org_list_from_url.RdGet the default organisation list from a git URL This function retrieves the default organisation list from a git URL. It checks if the organisation list is already cached in the user's R configuration. If it is, it returns the cached version. If not, it attempts to retrieve the organisation list from the specified git URL and caches it for future use.