Skip to contents

This function allows you to select a license for a project, package or dataset from the list of allowed licenses for the organisation. If there is only one license available, it will be selected automatically.

Usage

select_license(org, type = c("package", "project", "data"))

Arguments

org

An object of class org_list created with new_org_list() or org_list$new().

type

The type of license to select. One of "package", "project", or "data". Default is "package".

Value

The name of the selected license.