It only checks the format of the text, not if the email address exists.
See also
Other validation:
validate_citation(),
validate_language(),
validate_license(),
validate_orcid(),
validate_ror(),
validate_url()
It only checks the format of the text, not if the email address exists.
Other validation:
validate_citation(),
validate_language(),
validate_license(),
validate_orcid(),
validate_ror(),
validate_url()