Skip to contents

Validate a license list

Usage

validate_license(license)

Arguments

license

A list with three named character vectors: package, project, and data. Each vector should contain unique license names as values and unique package, project, or data names as names.

Value

Invisibly returns NULL if the license list is valid, otherwise throws an error.