Skip to contents

The Research Organization Registry (ROR) is a global, community-led registry of open persistent identifiers for research organizations. ROR makes it easy for anyone or any system to disambiguate institution names and connect research organizations to researchers and research outputs. Validate that a ROR is a string of 9 characters starting with 0, followed by 6 characters which can be a letter (except i, l, o) or a digit, and ending with 2 digits.

Usage

validate_ror(ror)

Arguments

ror

A ROR to validate.

Value

A logical value indicating whether the ROR is valid.