Ask for keywords This function prompts the user to enter one or more keywords separated by ;. It will continue to prompt the user until at least one keyword is provided. The function returns a character vector of the entered keywords, with leading and trailing whitespace removed.
Source: R/ask_keywords.R
ask_keywords.RdAsk for keywords
This function prompts the user to enter one or more keywords separated by
;.
It will continue to prompt the user until at least one keyword is provided.
The function returns a character vector of the entered keywords, with leading
and trailing whitespace removed.
See also
Other question:
ask_email(),
ask_language(),
ask_new_license(),
ask_orcid(),
ask_ror(),
ask_url(),
ask_yes_no(),
menu_first()