The ORCID iD is a unique, persistent identifier
free of charge to researchers.
This function prompts the user to enter an ORCID iD and validates its
format.
The ORCID iD must be in the format 0000-0000-0000-0000 where the last
digit can be a number or "X".
Empty strings are considered valid to allow optional ORCID iD.
See also
Other question:
ask_email(),
ask_language(),
ask_new_license(),
ask_ror(),
ask_url(),
ask_yes_no(),
menu_first()