The Research Organization Registry (ROR) is a global, community-led registry of open persistent identifiers for research organizations. ROR makes it easy for anyone or any system to disambiguate institution names and connect research organizations to researchers and research outputs.
See also
Other question:
ask_email(),
ask_language(),
ask_new_license(),
ask_orcid(),
ask_url(),
ask_yes_no(),
menu_first()