Provides a simple wrapper around utils::askYesNo().
This function is used to ask yes no questions in an interactive way.
It repeats the question until a valid answer is given.
Usage
ask_yes_no(msg, default = TRUE, prompts = c("Yes", "No", "Cancel"), ...)Arguments
- msg
The prompt message for the user.
- default
The default response.
- prompts
Any of: a character vector containing 3 prompts corresponding to return values of
TRUE,FALSE, orNA, or a single character value containing the prompts separated by/characters, or a function to call.- ...
Additional parameters, ignored by the default function.
See also
Other question:
ask_email(),
ask_language(),
ask_new_license(),
ask_orcid(),
ask_ror(),
ask_url(),
menu_first()