This function retrieves the organisation list from a given URL and caches it
locally.
If the URL is "https://github.com/inbo", it uses the default INBO
organisation list.
For other URLs, it checks if a public citeme repository exists and clones
it to retrieve the organisation list.
The cached organisation list is stored in a specified configuration folder.