Get the list of available organisations
Source:R/get_available_organisations.R
get_available_organisations.RdThis function retrieves the list of available organisations from the local configuration files. It returns a list containing the names, languages, licenses, ORCID, Zenodo, ROR, website, and logo of the available organisations.
Value
A list containing the names, languages, licenses, ORCID, Zenodo, ROR, website, and logo of the available organisations.
See also
Other organisation:
cache_org(),
get_default_org_list(),
inbo_org_list(),
new_org_item(),
new_org_list(),
org_list_from_url(),
select_license()