Select the individual information to use as a person object
Source: R/individual2person.R
individual2person.RdThis function retrieves the individual information using
select_individual() and converts it to a person object.
If the individual argument is not provided, it will prompt the user to
select an individual.
The person object will include the given name, family name, email, ORCID,
and affiliation (if available) of the selected individual.
See also
Other individual:
add_individual(),
individual2badge(),
individual2df(),
select_individual(),
store_individuals()