This function is a wrapper around utils::menu() that returns the index of
the first choice instead of the index of the selected choice.
This is useful when you want to ask a question with only one choice and you
want to return a logical value.
See also
Other question:
ask_email(),
ask_language(),
ask_new_license(),
ask_orcid(),
ask_ror(),
ask_url(),
ask_yes_no()