Skip to contents

Get the default organisation list from a git URL This function retrieves the default organisation list from a git URL. It checks if the organisation list is already cached in the user's R configuration. If it is, it returns the cached version. If not, it attempts to retrieve the organisation list from the specified git URL and caches it for future use.

Usage

org_list_from_url(git)

Arguments

git

The git URL to retrieve the organisation list from.

Value

An org_list object containing the organisation list.