Select an individual from the local database or add a new individual.
Source:R/select_individual.R
select_individual.RdReuse existing individual information or add a new individual. Allows to update existing individual information.
Usage
select_individual(email, lang, org = org_list$new()$read())Arguments
An optional email address. When given and it matches with a single person, the function immediately returns the information of that person.
- lang
The language to use for the affiliation. Defaults to the first language in the
namevector of theorg_listobject. When the affiliation is not available in that language, it will use the first available language.- org
An
org_listobject containing the organisation information. Defaults to theorg_listobject read from the current working directory.