Select an individual from the local database or add a new individual.
Source:R/use_individual.R
select_individual.RdReuse existing individual information or add a new individual. Allows to update existing individual information.
Arguments
An optional email address. When given and it matches with a single person, the function immediately returns the information of that person.
- lang
The language to use for the affiliation. Defaults to the first language in the
namevector of theorg_listobject. When the affiliation is not available in that language, it will use the first available language.
See also
Other individual:
add_individual(),
individual2badge(),
individual2df(),
individual2person(),
store_individuals()