This function allows you to select a license for a project, package or dataset from the list of allowed licenses for the organisation. If there is only one license available, it will be selected automatically.
Usage
select_license(org, type = c("package", "project", "data"))Arguments
- org
An object of class
org_listcreated withnew_org_list()ororg_list$new().- type
The type of license to select. One of
"package","project", or"data". Default is"package".
See also
Other organisation:
cache_org(),
get_available_organisations(),
get_default_org_list(),
inbo_org_list(),
new_org_item(),
new_org_list(),
org_list_from_url()